summaryrefslogtreecommitdiff
path: root/src/main/driver_unified.cpp
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-04-15 13:04:55 -0700
committerGitHub <noreply@github.com>2021-04-15 20:04:55 +0000
commit77bca094a140b35341257f125a55212ff0108250 (patch)
tree1d3369b9be5fc4c3e8cb279ae5ea662e59cbcb3e /src/main/driver_unified.cpp
parent63647b1d79df6f287ea6599958b16fce44b8271d (diff)
Rename occurrences of CVC4 to CVC5. (#6351)
This renames everything but GitHub links and build system related macros. Switching the build system to cvc5 will be the last step in the renaming process.
Diffstat (limited to 'src/main/driver_unified.cpp')
-rw-r--r--src/main/driver_unified.cpp25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/main/driver_unified.cpp b/src/main/driver_unified.cpp
index c5d89300c..2481eda10 100644
--- a/src/main/driver_unified.cpp
+++ b/src/main/driver_unified.cpp
@@ -10,7 +10,7 @@
* directory for licensing information.
* ****************************************************************************
*
* Driver for CVC4 executable (cvc4).
*/
#include <stdio.h>
@@ -78,11 +78,12 @@ TotalTimer::~TotalTimer()
void printUsage(Options& opts, bool full) {
stringstream ss;
- ss << "usage: " << opts.getBinaryName() << " [options] [input-file]"
- << endl << endl
- << "Without an input file, or with `-', CVC4 reads from standard input."
- << endl << endl
- << "CVC4 options:" << endl;
+ ss << "usage: " << opts.getBinaryName() << " [options] [input-file]" << endl
+ << endl
+ << "Without an input file, or with `-', cvc5 reads from standard input."
+ << endl
+ << endl
+ << "cvc5 options:" << endl;
if(full) {
Options::printUsage( ss.str(), *(opts.getOut()) );
} else {
@@ -151,7 +152,7 @@ int runCvc4(int argc, char* argv[], Options& opts) {
if(opts.getInputLanguage() == language::input::LANG_AUTO) {
if( inputFromStdin ) {
// We can't do any fancy detection on stdin
- opts.setInputLanguage(language::input::LANG_CVC4);
+ opts.setInputLanguage(language::input::LANG_CVC);
} else {
unsigned len = filenameStr.size();
if(len >= 5 && !strcmp(".smt2", filename + len - 5)) {
@@ -161,7 +162,7 @@ int runCvc4(int argc, char* argv[], Options& opts) {
opts.setInputLanguage(language::input::LANG_TPTP);
} else if(( len >= 4 && !strcmp(".cvc", filename + len - 4) )
|| ( len >= 5 && !strcmp(".cvc4", filename + len - 5) )) {
- opts.setInputLanguage(language::input::LANG_CVC4);
+ opts.setInputLanguage(language::input::LANG_CVC);
} else if((len >= 3 && !strcmp(".sy", filename + len - 3))
|| (len >= 3 && !strcmp(".sl", filename + len - 3))) {
// version 2 sygus is the default
@@ -211,17 +212,17 @@ int runCvc4(int argc, char* argv[], Options& opts) {
InteractiveShell shell(pExecutor->getSolver(),
pExecutor->getSymbolManager());
if(opts.getInteractivePrompt()) {
- CVC4Message() << Configuration::getPackageName() << " "
+ CVC5Message() << Configuration::getPackageName() << " "
<< Configuration::getVersionString();
if(Configuration::isGitBuild()) {
- CVC4Message() << " [" << Configuration::getGitId() << "]";
+ CVC5Message() << " [" << Configuration::getGitId() << "]";
}
- CVC4Message() << (Configuration::isDebugBuild() ? " DEBUG" : "")
+ CVC5Message() << (Configuration::isDebugBuild() ? " DEBUG" : "")
<< " assertions:"
<< (Configuration::isAssertionBuild() ? "on" : "off")
<< endl
<< endl;
- CVC4Message() << Configuration::copyright() << endl;
+ CVC5Message() << Configuration::copyright() << endl;
}
while(true) {
generated by cgit on debian on lair
@@ -10,7 +10,7 @@
* ****************************************************************************
*
- * Driver for CVC4 executable (cvc4).
+ * Driver for cvc5 executable (cvc4).
*/
#include <stdio.h>
contact matthew@masot.net with questions or feedback